==> haskell-data-serializer-0.3-20-i686.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3
id: data-serializer-0.3-BrAt8AyNlBe7GhBJpBmt70
key: data-serializer-0.3-BrAt8AyNlBe7GhBJpBmt70
license: BSD3
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Deserializer Data.Serializer
abi: ea77bc0fb9fac1def0d0103b267bf939
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/data-serializer-0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/data-serializer-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/data-serializer-0.3
hs-libraries: HSdata-serializer-0.3-BrAt8AyNlBe7GhBJpBmt70
depends:
    base-4.10.0.0 semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    bytestring-0.10.8.2 binary-0.8.5.1
    cereal-0.5.4.0-AV9aAoAC3OtC6kJvAolohE
    data-endian-0.1.1-EiBKMMGvTe28FrP9GqXeJ9
    parsers-0.12.7-C34JrySfMrGGlqNn6MwWT6
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             cereal-0.5.4.0-AV9aAoAC3OtC6kJvAolohE=45711223006f2eb72f62bbe45f216d21
             data-endian-0.1.1-EiBKMMGvTe28FrP9GqXeJ9=1430d15b1182d466c9efa8e841369a27
             parsers-0.12.7-C34JrySfMrGGlqNn6MwWT6=e3be2d1f5e848de17c34348318e68634
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-serializer-0.3-21-i686.pkg.tar.xz: usr/share/haskell/register/haskell-data-serializer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-serializer
version: 0.3
id: data-serializer-0.3-LlTCYl0DmfsGcIgiQzgpbB
key: data-serializer-0.3-LlTCYl0DmfsGcIgiQzgpbB
license: BSD3
copyright: 2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-serializer
synopsis: Common API for serialization libraries
description:
    This package provides a common API for serialization libraries like
    <http://hackage.haskell.org/package/binary binary> and
    <http://hackage.haskell.org/package/cereal cereal>.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Deserializer Data.Serializer
abi: 855c180a5263de8294010b9d7f082a52
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/data-serializer-0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/data-serializer-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/data-serializer-0.3
hs-libraries: HSdata-serializer-0.3-LlTCYl0DmfsGcIgiQzgpbB
depends:
    base-4.10.0.0 semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    bytestring-0.10.8.2 binary-0.8.5.1
    cereal-0.5.4.0-AV9aAoAC3OtC6kJvAolohE
    data-endian-0.1.1-EiBKMMGvTe28FrP9GqXeJ9
    parsers-0.12.7-1kfASGSbUOaHyymSJg92ek
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             cereal-0.5.4.0-AV9aAoAC3OtC6kJvAolohE=45711223006f2eb72f62bbe45f216d21
             data-endian-0.1.1-EiBKMMGvTe28FrP9GqXeJ9=1430d15b1182d466c9efa8e841369a27
             parsers-0.12.7-1kfASGSbUOaHyymSJg92ek=28f5d89af564c00015ae8eb2097c2ac7
haddock-interfaces: /usr/share/doc/haskell-data-serializer/html/data-serializer.haddock
haddock-html: /usr/share/doc/haskell-data-serializer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
